import { metaData } from '@cornerstonejs/core';
const groupBy = (array, key) => {
    return array.reduce((rv, x) => {
        (rv[x[key]] = rv[x[key]] || []).push(x);
        return rv;
    }, {});
};
function splitFramesByMetadata(imageIds, metadataField, property) {
    const framesMetadata = imageIds.map((imageId) => {
        const moduleInfo = metaData.get(metadataField, imageId);
        const propInfo = moduleInfo ? moduleInfo[property] : 0;
        return { imageId, [property]: propInfo };
    });
    if (!framesMetadata.every((item) => item[property])) {
        return null;
    }
    const framesGroups = groupBy(framesMetadata, property);
    const sortedKeys = Object.keys(framesGroups)
        .map(Number.parseFloat)
        .sort((a, b) => a - b);
    const imageIdsGroups = sortedKeys.map((key) => framesGroups[key].map((item) => item.imageId));
    return imageIdsGroups;
}
function splitImageIdsBy4DTags(imageIds) {
    const fncList = [
        (imageIds) => splitFramesByMetadata(imageIds, 'petImageModule', 'frameReferenceTime'),
        (imageIds) => splitFramesByMetadata(imageIds, 'temporalPositionIdentifier', 'temporalPositionIdentifier'),
    ];
    for (let i = 0; i < fncList.length; i++) {
        const framesGroups = fncList[i](imageIds);
        if (!framesGroups || framesGroups.length <= 1) {
            continue;
        }
        const framesPerGroup = framesGroups[0].length;
        const groupsHaveSameLength = framesGroups.every((g) => g.length === framesPerGroup);
        if (groupsHaveSameLength) {
            return framesGroups;
        }
    }
    return [imageIds];
}
export default splitImageIdsBy4DTags;
//# sourceMappingURL=splitImageIdsBy4DTags.js.map